==> nextcloud-21.0.0p0.tgz: nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Le mot de passe a expiré, veuillez utiliser la fonction mot de passe perdu pour le ré-initialiser",
    "Password must not have been used recently before." : "Le mot de passe ne doit pas avoir été utilisé récemment.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 de mots de passe les plus courants. Merci de le rendre unique.",
    "Password is present in compromised password list. Please choose a different password." : "Le mot de passe est présent dans la liste des mots de passe compromis. Merci d'en choisir un autre.",
    "Password needs to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password policy" : "Politique de mots de passe",
    "Allows admins to configure a password policy" : "Permet aux administrateurs de configurer une politique de mot de passe.",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permettre à l'administrateur de définir certaines conditions préalables pour le mot de passe, par exemple, imposer une longueur minimale.",
    "Minimum password length" : "Longueur minimale du mot de passe",
    "User password history" : "Historique des mots de passe de l'utilisateur",
    "Number of days until user password expires" : "Nombre de jours avant expiration du mot de passe",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Nombre de tentatives de connexion avant de verrouiller le compte utilisateur (0 pour indiquer aucune limite)",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cette vérification crée un hachage du mot de passe et envoie les 5 premiers caractères de ce hachage à l'API haveibeenpwned.com pour récupérer une liste de tous les hachages qui commencent par ceux-là. Ensuite, il vérifie sur l'instance Nextcloud si le mot de passe est dans le jeu de résultats.",
    "Minimal length" : "Taille minimale",
    "days until user password expires" : "jours restants avant expiration du mot de passe",
    "login attempts before the user account is blocked. (0 for no limit)" : "Nombre de tentatives de connexion avant de verrouiller le compte utilisateur (0 pour indiquer aucune limite)"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-22.2.0.tgz: nextcloud/apps/password_policy/l10n/fr.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Le mot de passe a expiré, veuillez utiliser la fonction mot de passe perdu pour le ré-initialiser",
    "Password must not have been used recently before." : "Le mot de passe ne doit pas avoir été utilisé récemment.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Le mot de passe se trouve parmi les 1 000 000 de mots de passe les plus courants. Merci de le rendre unique.",
    "Password is present in compromised password list. Please choose a different password." : "Le mot de passe est présent dans la liste des mots de passe compromis. Merci d'en choisir un autre.",
    "Password needs to be at least %s characters long." : "Le mot de passe doit comporter au moins %s caractères.",
    "Password needs to contain at least one numeric character." : "Le mot de passe doit contenir au moins un chiffre.",
    "Password needs to contain at least one special character." : "Le mot de passe doit contenir au moins un caractère spécial.",
    "Password needs to contain at least one lower and one upper case character." : "Le mot de passe doit contenir au moins un caractère en minuscule et un caractère en majuscule.",
    "Password policy" : "Politique de mots de passe",
    "Allows admins to configure a password policy" : "Permet aux administrateurs de configurer une politique de mot de passe.",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Permettre à l'administrateur de définir certaines conditions préalables pour le mot de passe, par exemple, imposer une longueur minimale.",
    "Saved" : "Enregistré",
    "Minimum password length" : "Longueur minimale du mot de passe",
    "User password history" : "Historique des mots de passe de l'utilisateur",
    "Number of days until user password expires" : "Nombre de jours avant expiration du mot de passe",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Nombre de tentatives de connexion avant de verrouiller le compte utilisateur (0 pour indiquer aucune limite)",
    "Forbid common passwords" : "Interdire les mots de passe courants",
    "Enforce upper and lower case characters" : "Imposer des caractères en majuscules et en minuscules",
    "Enforce numeric characters" : "Imposer des chiffres",
    "Enforce special characters" : "Imposer des caractères spéciaux",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Vérifier le mot de passe par rapport à la liste des mots de passe violés sur haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Cette vérification crée un hachage du mot de passe et envoie les 5 premiers caractères de ce hachage à l'API haveibeenpwned.com pour récupérer une liste de tous les hachages qui commencent par ceux-là. Ensuite, il vérifie sur l'instance Nextcloud si le mot de passe est dans le jeu de résultats.",
    "Unknown error" : "Erreur inconnue",
    "Minimal length has to be a non negative number" : "La longueur minimale doit être un nombre positif",
    "History size has to be a non negative number" : "La taille de l'historique doit être un nombre positif",
    "Expiration days have to be a non negative number" : "La date d'expiration doit être un nombre positif",
    "Maximum login attempts have to be a non negative number" : "Le nombre de tentatives de connexion doit être un nombre positif",
    "Password needs to be at least %s characters long" : "Le mot de passe doit comporter au moins %s caractères",
    "Minimal length" : "Taille minimale",
    "days until user password expires" : "jours restants avant expiration du mot de passe",
    "login attempts before the user account is blocked. (0 for no limit)" : "Nombre de tentatives de connexion avant de verrouiller le compte utilisateur (0 pour indiquer aucune limite)"
},
"nplurals=2; plural=(n > 1);");
